@@ -18,11 +18,7 @@
 #include <QTime>
 #include <QTimer>
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
+#include <QtGui/private/qtx11extras_p.h>
 
 xcb_screen_t *XRandR::s_screen = nullptr;
 xcb_window_t XRandR::s_rootWindow = 0;
@@ -152,10 +148,9 @@ void XRandR::crtcChanged(xcb_randr_crtc_t crtc, xcb_randr_mode_t mode, xcb_randr
     if (!xCrtc) {
         s_internalConfig->addNewCrtc(crtc);
         xCrtc = s_internalConfig->crtc(crtc);
-    } else {
-        xCrtc->update(mode, rotation, geom);
     }
 
+    xCrtc->update(mode, rotation, geom); // BUG 472280 Still need to call update(...) because the timestamp is newer
     xCrtc->updateConfigTimestamp(timestamp);
     m_configChangeCompressor->start();
 }
@@ -209,17 +204,18 @@ bool XRandR::isValid() const
 
 quint8 *XRandR::getXProperty(xcb_randr_output_t output, xcb_atom_t atom, size_t &len)
 {
-    quint8 *result;
+    quint8 *result = nullptr;
 
     auto cookie = xcb_randr_get_output_property(XCB::connection(), output, atom, XCB_ATOM_ANY, 0, 100, false, false);
     auto reply = xcb_randr_get_output_property_reply(XCB::connection(), cookie, nullptr);
+    if (!reply) {
+        return result;
+    }
 
     if (reply->type == XCB_ATOM_INTEGER && reply->format == 8) {
         result = new quint8[reply->num_items];
         memcpy(result, xcb_randr_get_output_property_data(reply), reply->num_items);
         len = reply->num_items;
-    } else {
-        result = nullptr;
     }
 
     free(reply);
@@ -296,3 +292,5 @@ xcb_screen_t *XRandR::screen()
 {
     return s_screen;
 }
+
+#include "moc_xrandr.cpp"
