@@ -20,8 +20,6 @@
 #include <xcb/randr.h>
 #include <xcb/render.h>
 
-Q_DECLARE_METATYPE(QList<int>)
-
 #define DOUBLE_TO_FIXED(d) ((xcb_render_fixed_t)((d)*65536))
 #define FIXED_TO_DOUBLE(f) ((double)((f) / 65536.0))
 
@@ -73,11 +71,13 @@ uint32_t XRandROutput::priority() const
 
 void XRandROutput::setPriority(XRandROutput::Priority newPriority)
 {
-    if (priority() == newPriority) {
-        return;
+    if (priority() != newPriority) {
+        setOutputPriorityToProperty(newPriority);
     }
 
-    setOutputPriorityToProperty(newPriority);
+    // Always update the primary regardless of it having changed. If a primary gets unplugged and plugged back in we'd
+    // otherwise end up with priorities not being in sync with xrandr primary because the effective priorities in the
+    // atoms haven't changed; also see priority().
     if (newPriority == 1) {
         setAsPrimary();
     }
@@ -125,7 +125,8 @@ KScreen::Output::Rotation XRandROutput::rotation() const
 bool XRandROutput::isHorizontal() const
 {
     const auto rot = rotation();
-    return rot == KScreen::Output::Rotation::None || rot == KScreen::Output::Rotation::Inverted;
+    return rot == KScreen::Output::Rotation::None || rot == KScreen::Output::Rotation::Inverted || rot == KScreen::Output::Rotation::Flipped
+        || rot == KScreen::Output::Rotation::Flipped180;
 }
 
 QByteArray XRandROutput::edid() const
@@ -177,6 +178,7 @@ void XRandROutput::update(xcb_randr_crtc_t crtc, xcb_randr_mode_t mode, xcb_rand
         }
 
         m_hotplugModeUpdate = XRandR::hasProperty(m_id, "hotplug_mode_update");
+        m_edid.clear();
     }
 
     // A monitor has been enabled or disabled
@@ -498,3 +500,5 @@ KScreen::OutputPtr XRandROutput::toKScreenOutput() const
     kscreenOutput->blockSignals(signalsBlocked);
     return kscreenOutput;
 }
+
+#include "moc_xrandroutput.cpp"
